Constructs a TmCRQuery object for the given MBTA commuter rail route.
Calling $stop() on a terminus station will issue a warning because stop IDs
are often missing in one direction at termini, making headway/dwell data
potentially incomplete.
Arguments
- route
CR route ID, e.g.
"CR-Fairmount","CR-Lowell". Usetm_cr_routes()to see all valid route IDs.- base_url
API base URL. Defaults to the production host or the
tm_dashboard_base_urloption.